%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}

Name:           netty
Version:        4.1.51
Release:        %mkrel 1
Group:          Development/Java
Summary:        An asynchronous event-driven network application framework and tools for Java
License:        ASL 2.0
URL:            https://netty.io/
Source0:        https://github.com/netty/netty/archive/netty-%{namedversion}.tar.gz
# Upsteam uses a simple template generator script written in groovy and run with gmaven
# We don't have the plugin and want to avoid groovy dependency
# This script is written in bash+sed and performs the same task
Source1:        codegen.bash
Patch0:         0001-Remove-optional-dep-Blockhound.patch
Patch1:         0002-Remove-optional-dep-conscrypt.patch
Patch2:         0003-Remove-optional-deps-jetty-alpn-and-npn.patch
Patch3:         0004-Remove-optional-dep-tcnative.patch
Patch4:         0005-Remove-optional-dep-log4j.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.jcraft:jzlib)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(kr.motd.maven:os-maven-plugin)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.bouncycastle:bcpkix-jdk15on)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.jctools:jctools-core)
BuildRequires:  mvn(org.slf4j:slf4j-api)

BuildArch: noarch

%description
Netty is a NIO client server framework which enables quick and easy
development of network applications such as protocol servers and
clients. It greatly simplifies and streamlines network programming
such as TCP and UDP socket server.

'Quick and easy' doesn't mean that a resulting application will suffer
from a maintainability or a performance issue. Netty has been designed
carefully with the experiences earned from the implementation of a lot
of protocols such as FTP, SMTP, HTTP, and various binary and
text-based legacy protocols. As a result, Netty has succeeded to find
a way to achieve ease of development, performance, stability, and
flexibility without a compromise.

%package javadoc
Summary:   API documentation for %{name}

%description javadoc
%{summary}.

%prep
%setup -q -n netty-netty-%{namedversion}

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

# remove unnecessary dependency on parent POM
%pom_remove_parent . bom dev-tools

# Disable all in one jar
%pom_disable_module all

# Not needed for RPM builds
%pom_disable_module "example"
%pom_disable_module "tarball"
%pom_disable_module "microbench"

%pom_xpath_inject 'pom:plugin[pom:artifactId="maven-remote-resources-plugin"]' '
<dependencies>
<dependency>
<groupId>io.netty</groupId>
<artifactId>netty-dev-tools</artifactId>
<version>${project.version}</version>
</dependency>
</dependencies>'

%pom_remove_plugin :maven-antrun-plugin
%pom_remove_plugin :maven-dependency-plugin
%pom_remove_plugin :xml-maven-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :animal-sniffer-maven-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r :maven-release-plugin
%pom_remove_plugin -r :maven-clean-plugin
%pom_remove_plugin -r :maven-source-plugin
%pom_remove_plugin -r :maven-deploy-plugin
%pom_remove_plugin -r :maven-jxr-plugin
%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :forbiddenapis

cp %{SOURCE1} common/codegen.bash
%pom_add_plugin org.codehaus.mojo:exec-maven-plugin common '
<executions>
    <execution>
        <id>generate-collections</id>
        <phase>generate-sources</phase>
        <goals>
            <goal>exec</goal>
        </goals>
        <configuration>
            <executable>common/codegen.bash</executable>
        </configuration>
    </execution>
</executions>
'
%pom_remove_plugin :groovy-maven-plugin common

# We don't have com.oracle.substratevm
%pom_remove_dep "com.oracle.substratevm:" common
rm common/src/main/java/io/netty/util/internal/svm/*

# The protobuf-javanano API was discontinued upstream and obsoleted in Fedora
# so disable support for protobuf in the codecs module
%pom_remove_dep -r "com.google.protobuf:protobuf-java"
%pom_remove_dep -r "com.google.protobuf.nano:protobuf-javanano"
rm codec/src/main/java/io/netty/handler/codec/protobuf/*
sed -i '/import.*protobuf/d' codec/src/main/java/io/netty/handler/codec/DatagramPacket*.java

# JBoss marshalling not available in Fedora
%pom_remove_dep -r "org.jboss.marshalling:jboss-marshalling"
rm codec/src/main/java/io/netty/handler/codec/marshalling/*

# Various compression codecs not available in Fedora
%pom_remove_dep -r com.github.jponge:lzma-java
rm codec/src/*/java/io/netty/handler/codec/compression/Lzma*.java
%pom_remove_dep -r com.ning:compress-lzf
rm codec/src/*/java/io/netty/handler/codec/compression/Lzf*.java
%pom_remove_dep -r net.jpountz.lz4:lz4
rm codec/src/*/java/io/netty/handler/codec/compression/Lz4*.java

# Disable other codecs with extra dependencies
%pom_remove_dep -r com.fasterxml:aalto-xml
%pom_disable_module codec-xml

# Disable unneeded transport artifacts
%pom_disable_module transport-native-epoll
%pom_disable_module transport-native-kqueue
%pom_disable_module transport-native-unix-common
%pom_disable_module transport-rxtx
%pom_disable_module transport-sctp
%pom_disable_module transport-udt

# Disable macos native bit
%pom_disable_module resolver-dns-native-macos

# Disable test suites
%pom_disable_module testsuite
%pom_disable_module testsuite-autobahn
%pom_disable_module testsuite-http2
%pom_disable_module testsuite-native-image
%pom_disable_module testsuite-osgi
%pom_disable_module testsuite-shading
%pom_disable_module transport-native-unix-common-tests

# Upstream has jctools bundled.
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId = 'maven-bundle-plugin']/pom:executions/pom:execution[pom:id = 'generate-manifest']/pom:configuration/pom:instructions/pom:Import-Package" common/pom.xml

# Tell xmvn to install attached artifact, which it does not
# do by default. In this case install all attached artifacts with
# the linux classifier.
%mvn_package ":::linux*:"

%build
# Ensure we use distro compile flags
export CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$RPM_LD_FLAGS"

%mvn_build -f -- -Dsource=1.8

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Fri Sep 11 2020 daviddavid <daviddavid> 4.1.51-1.mga8
+ Revision: 1624352
- Update to latest upstream version 4.1.51
- Native bits were not used by anything, so package is now noarch

* Thu Sep 03 2020 daviddavid <daviddavid> 4.1.13-19.mga8
+ Revision: 1621287
- Don't ship the bundled all-in-one jar
- Fix java 11 build
- Rebuilt for JDK-11
- Remove unnecessary dependency on parent POM

* Sat Feb 15 2020 umeabot <umeabot> 4.1.13-3.mga8
+ Revision: 1527620
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 4.1.13-2.mga8
+ Revision: 1422491
- Add more artifacts to the jp_minimal conditional
- Disable support for protobuf in the codecs module due to the javanano API
  being discontinued upstream and obsoleted in Fedora

* Mon Dec 03 2018 daviddavid <daviddavid> 4.1.13-1.mga7
+ Revision: 1337948
- new version: 4.1.13 (sync with fc29)
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 4.0.28-3.mga6
+ Revision: 977740
- First rebuild of the java stack
- sync package netty with fedora
- Rebuild against current java stack
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri May 22 2015 luigiwalser <luigiwalser> 4.0.28-1.mga5
+ Revision: 822589
- 4.0.28 (fixes CVE-2015-2156, sync with f21)

* Fri Dec 26 2014 pterjan <pterjan> 4.0.19-2.mga5
+ Revision: 806312
- Clean rebuild
- Disable transport-native-epoll plugin for now
- Sync with Fedora 21 (update to 4.0.19)
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild
+ dmorgan <dmorgan>
- New version

* Sun Sep 15 2013 dmorgan <dmorgan> 3.6.3-3.mga4
+ Revision: 479894
- Set scope of optional compile dependencies to provided
- Drop dependency on OSGi
- Resolves: rhbz#916139

* Sun Sep 15 2013 dmorgan <dmorgan> 3.6.3-1.mga4
+ Revision: 479815
- Update to upstream version 3.6.3

* Fri Jul 12 2013 dmorgan <dmorgan> 3.6.2-1.mga4
+ Revision: 453276
- New version

* Thu Jul 11 2013 dmorgan <dmorgan> 3.6.1-1.mga4
+ Revision: 453193
- New version
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 dmorgan <dmorgan> 3.5.11-2.mga3
+ Revision: 339018
- New version

* Tue Dec 04 2012 dmorgan <dmorgan> 3.5.9-1.mga3
+ Revision: 326378
- New version

* Mon Dec 03 2012 dmorgan <dmorgan> 3.5.8-1.mga3
+ Revision: 325730
- New version

* Wed Sep 12 2012 dmorgan <dmorgan> 3.5.7-1.mga3
+ Revision: 292785
- New version

* Sun Sep 09 2012 dmorgan <dmorgan> 3.2.4-2.mga3
+ Revision: 291469
- Add enforcer-plugin to BR

* Mon Jun 25 2012 dmorgan <dmorgan> 3.2.4-1.mga3
+ Revision: 263738
- New version 3.2.4

* Sat Jul 23 2011 dmorgan <dmorgan> 3.2.3-5.mga2
+ Revision: 128111
- Add buildrequire
- Fix FTBFS.
    - Adapt to current guidelines.

* Wed Apr 27 2011 dmorgan <dmorgan> 3.2.3-4.mga1
+ Revision: 91987
- Rebuild after bootstrapping
- imported package netty


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 17 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.2.3-2
- Use maven 3 to build
- Drop ant-contrib depmap (no longer needed)

* Thu Jan 13 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.2.3-1
- Initial version of the package

